@@ -1,7 +1,8 @@
 from __future__ import annotations
+from typing import Optional
 
 class CommandLineError(Exception):
-    def __init__(self, msg: str, src_err: ValidationError):
+    def __init__(self, msg: str, src_err: Optional[ValidationError] = None):
         super().__init__(msg)
         self.msg = msg
         self.src_err = src_err
@@ -11,5 +12,7 @@ class ValidationError(Exception):
         super().__init__(msg)
         self.msg = msg
 
-class TemplateError(ValidationError):
-    pass
\ No newline at end of file
+class TemplateError(Exception):
+    def __init__(self, msg: str):
+        super().__init__(msg)
+        self.msg = msg
\ No newline at end of file
